import Vue from 'vue'
import Router from 'vue-router'
import Layout from '@/views/layout/index.vue'
import demo from './modules/demo' // 统计数据展示（PC端）
import drag from './modules/drag' // 统计数据展示（PC端）

Vue.use(Router)

export const constantRouterMap = [
  {
    path: '/login',
    name: 'login',
    component: () => import('@/views/login/login.vue'),
    meta: {
      anonymous: true,
      hidden: true
    }
  }
]
export const asyncRouterMap = [
  {
    path: '/',
    redirect: '/drag/drag-painting',
    meta: {
      public: true,
      hidden: true
    }
  },
  demo,
  drag,
  {
    path: '/drag-demo',
    name: 'dragDemo',
    component: () => import('@/views/drag/drag_demo/index.vue'),
    meta: {
      title: '页面展示',
      public: true,
      hidden: true
    }
  },
  {
    path: '',
    component: Layout,
    meta: {
      public: true,
      hidden: true
    },
    children: [
      {
        path: '*',
        name: '404',
        component: () => import('@/views/common/404.vue'),
        meta: {
          title: '404',
          public: true,
          hidden: true
        }
      }
    ]
  }
]
const createRouter = () =>
  new Router({
    base: process.env.VUE_APP_BASE_URL || '/',
    mode: 'history',
    routes: [...constantRouterMap, ...asyncRouterMap]
  })

const router = createRouter()

export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

// 解决ElementUI导航中的vue-router在3.0版本以上重复点菜单报错问题
const originalPush = Router.prototype.push
Router.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err)
}

export default router
